summaryrefslogtreecommitdiffstats
path: root/kmymoney2/plugins/viewinterface.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/plugins/viewinterface.h')
-rw-r--r--kmymoney2/plugins/viewinterface.h25
1 files changed, 13 insertions, 12 deletions
diff --git a/kmymoney2/plugins/viewinterface.h b/kmymoney2/plugins/viewinterface.h
index d7c7424..edec926 100644
--- a/kmymoney2/plugins/viewinterface.h
+++ b/kmymoney2/plugins/viewinterface.h
@@ -25,10 +25,10 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qobject.h>
-#include <qstring.h>
-#include <qpixmap.h>
-class QFrame;
+#include <tqobject.h>
+#include <tqstring.h>
+#include <tqpixmap.h>
+class TQFrame;
// ----------------------------------------------------------------------------
// KDE Includes
@@ -53,27 +53,28 @@ namespace KMyMoneyPlugin {
* add new view pages to the JanusWidget of KMyMoney. It
* also gives access to the account context menu.
*/
-class KMYMONEY_EXPORT ViewInterface : public QObject {
+class KMYMONEY_EXPORT ViewInterface : public TQObject {
Q_OBJECT
+ TQ_OBJECT
public:
- ViewInterface(QObject* parent, const char* name = 0);
+ ViewInterface(TQObject* tqparent, const char* name = 0);
~ViewInterface() {}
/**
* This method creates a new page in the application.
* See KJanusWidget::addPage() for details.
*/
- virtual KMyMoneyViewBase* addPage(const QString& item, const QString& icon) = 0;
+ virtual KMyMoneyViewBase* addPage(const TQString& item, const TQString& icon) = 0;
/**
- * This method adds a widget to the layout of the view
+ * This method adds a widget to the tqlayout of the view
* created with addPage()
*
* @param view pointer to view widget
* @param w widget to be added to @p page
*/
- virtual void addWidget(KMyMoneyViewBase* view, QWidget* w) = 0;
+ virtual void addWidget(KMyMoneyViewBase* view, TQWidget* w) = 0;
signals:
/**
@@ -87,7 +88,7 @@ signals:
/**
* This signal is emitted when a transaction/list of transactions has been selected by
* the GUI. If no transaction is selected or the selection is removed,
* @p transactions is identical to an empty QValueList. This signal is used
* by plugins to get information about changes.
*/
void transactionsSelected(const KMyMoneyRegister::SelectedTransactions& transactions);
@@ -109,10 +110,10 @@ signals:
* @param date the reconciliation date as provided through the dialog
* @param startingBalance the starting balance as provided through the dialog
* @param endingBalance the ending balance as provided through the dialog
* @param transactionList reference to QValueList of QPair containing all
* transaction/split pairs processed by the reconciliation.
*/
- void accountReconciled(const MyMoneyAccount& account, const QDate& date, const MyMoneyMoney& startingBalance, const MyMoneyMoney& endingBalance, const QValueList<QPair<MyMoneyTransaction, MyMoneySplit> >& transactionList);
+ void accountReconciled(const MyMoneyAccount& account, const TQDate& date, const MyMoneyMoney& startingBalance, const MyMoneyMoney& endingBalance, const TQValueList<TQPair<MyMoneyTransaction, MyMoneySplit> >& transactionList);
void viewStateChanged(bool);
@@ -87,7 +88,7 @@ signals:
* This signal is emitted when a transaction/list of transactions has been selected by
* the GUI. If no transaction is selected or the selection is removed,
- * @p transactions is identical to an empty QValueList. This signal is used
+ * @p transactions is identical to an empty TQValueList. This signal is used
* by plugins to get information about changes.
*/
@@ -109,10 +110,10 @@ signals:
* @param startingBalance the starting balance as provided through the dialog
* @param endingBalance the ending balance as provided through the dialog
- * @param transactionList reference to QValueList of QPair containing all
+ * @param transactionList reference to TQValueList of TQPair containing all
* transaction/split pairs processed by the reconciliation.
*/